==> ejc-budgetmanage-impl-3.0.0-20230324.091733-161-sources.jar: com/ejianc/business/bedget/vo/PaymentDetailVO.java <==
package com.ejianc.business.bedget.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 付款登记子表
 * 
 * @author generator
 * 
 */
public class PaymentDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long projectId; // 项目主键
    private String projectName; // 项目名称
    private Long paymentId; // 主表主键
    private Long contractId; // 合同主键
    private String contractName; // 合同名称
    private String contractCode; // 合同编号
    private Long supplierId; // 分包分供id
    private String supplierName; // 分包分供名称
    private String subcontractType; // 分包类型
    private BigDecimal contractAmountTax; // 合同额（含税）
    private String isComplete; // 是否完工结算 是/否
    private BigDecimal settlementMoneyTotal; // 累计结算金额（含税）
    private BigDecimal copeWithRatioTotal; // 应付比例%
    private BigDecimal advanceTotal; // 累计应付金额  预付账款
    private BigDecimal scheduleTotal; // 累计应付金额  进度账款
    private BigDecimal pastAdvanceTotal;//往期累计预付账款
    private BigDecimal pastScheduleTotal;//往期累计进度账款
    private BigDecimal accountsPayableTotal; // 累计应付金额合计
    private BigDecimal currentAdvanceMoney; // 本期实付金额 预付款金额
    private BigDecimal currentScheduleMoney; // 本期实付金额 进度款
    private BigDecimal currentMoneyTotal; // 本期实付金额合计
    private BigDecimal paymentAdvanceMoney; // 累计付款金额（含本期) 预付账款
    private BigDecimal paymentScheduleMoney; // 累计付款金额（含本期) 进度账款
    private BigDecimal paymentMoneyTotal; // 累计付款金额（含本期）合计
    private BigDecimal paymentCopeWithRatio; // 累计付款金额（含本期)  累计支付比例%
    private BigDecimal debtAdvanceMoney; // 累计欠款金额 预付账款
    private BigDecimal debtScheduleMoney; // 累计欠款金额 进度账款
    private BigDecimal debtMoneyTotal; // 累计欠款金额 合计
    private BigDecimal taxCurrentTotal; // 中间计量含税金额
    private BigDecimal totalMoneyTax; // 最终结算含税金额

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public Long getPaymentId() {
        return paymentId;
    }

    public void setPaymentId(Long paymentId) {
        this.paymentId = paymentId;
    }

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }

    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }

    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }

    public String getSubcontractType() {
        return subcontractType;
    }

    public void setSubcontractType(String subcontractType) {
        this.subcontractType = subcontractType;
    }

    public BigDecimal getContractAmountTax() {
        return contractAmountTax;
    }

    public void setContractAmountTax(BigDecimal contractAmountTax) {
        this.contractAmountTax = contractAmountTax;
    }

    public String getIsComplete() {
        return isComplete;
    }

    public void setIsComplete(String isComplete) {
        this.isComplete = isComplete;
    }

    public BigDecimal getSettlementMoneyTotal() {
        return settlementMoneyTotal;
    }

    public void setSettlementMoneyTotal(BigDecimal settlementMoneyTotal) {
        this.settlementMoneyTotal = settlementMoneyTotal;
    }

    public BigDecimal getCopeWithRatioTotal() {
        return copeWithRatioTotal;
    }

    public void setCopeWithRatioTotal(BigDecimal copeWithRatioTotal) {
        this.copeWithRatioTotal = copeWithRatioTotal;
    }

    public BigDecimal getAdvanceTotal() {
        return advanceTotal;
    }

    public void setAdvanceTotal(BigDecimal advanceTotal) {
        this.advanceTotal = advanceTotal;
    }

    public BigDecimal getScheduleTotal() {
        return scheduleTotal;
    }

    public void setScheduleTotal(BigDecimal scheduleTotal) {
        this.scheduleTotal = scheduleTotal;
    }

    public BigDecimal getPastAdvanceTotal() {
        return pastAdvanceTotal;
    }

    public void setPastAdvanceTotal(BigDecimal pastAdvanceTotal) {
        this.pastAdvanceTotal = pastAdvanceTotal;
    }

    public BigDecimal getPastScheduleTotal() {
        return pastScheduleTotal;
    }

    public void setPastScheduleTotal(BigDecimal pastScheduleTotal) {
        this.pastScheduleTotal = pastScheduleTotal;
    }

    public BigDecimal getAccountsPayableTotal() {
        return accountsPayableTotal;
    }

    public void setAccountsPayableTotal(BigDecimal accountsPayableTotal) {
        this.accountsPayableTotal = accountsPayableTotal;
    }

    public BigDecimal getCurrentAdvanceMoney() {
        return currentAdvanceMoney;
    }

    public void setCurrentAdvanceMoney(BigDecimal currentAdvanceMoney) {
        this.currentAdvanceMoney = currentAdvanceMoney;
    }

    public BigDecimal getCurrentScheduleMoney() {
        return currentScheduleMoney;
    }

    public void setCurrentScheduleMoney(BigDecimal currentScheduleMoney) {
        this.currentScheduleMoney = currentScheduleMoney;
    }

    public BigDecimal getCurrentMoneyTotal() {
        return currentMoneyTotal;
    }

    public void setCurrentMoneyTotal(BigDecimal currentMoneyTotal) {
        this.currentMoneyTotal = currentMoneyTotal;
    }

    public BigDecimal getPaymentAdvanceMoney() {
        return paymentAdvanceMoney;
    }

    public void setPaymentAdvanceMoney(BigDecimal paymentAdvanceMoney) {
        this.paymentAdvanceMoney = paymentAdvanceMoney;
    }

    public BigDecimal getPaymentScheduleMoney() {
        return paymentScheduleMoney;
    }

    public void setPaymentScheduleMoney(BigDecimal paymentScheduleMoney) {
        this.paymentScheduleMoney = paymentScheduleMoney;
    }

    public BigDecimal getPaymentMoneyTotal() {
        return paymentMoneyTotal;
    }

    public void setPaymentMoneyTotal(BigDecimal paymentMoneyTotal) {
        this.paymentMoneyTotal = paymentMoneyTotal;
    }

    public BigDecimal getPaymentCopeWithRatio() {
        return paymentCopeWithRatio;
    }

    public void setPaymentCopeWithRatio(BigDecimal paymentCopeWithRatio) {
        this.paymentCopeWithRatio = paymentCopeWithRatio;
    }

    public BigDecimal getDebtAdvanceMoney() {
        return debtAdvanceMoney;
    }

    public void setDebtAdvanceMoney(BigDecimal debtAdvanceMoney) {
        this.debtAdvanceMoney = debtAdvanceMoney;
    }

    public BigDecimal getDebtScheduleMoney() {
        return debtScheduleMoney;
    }

    public void setDebtScheduleMoney(BigDecimal debtScheduleMoney) {
        this.debtScheduleMoney = debtScheduleMoney;
    }

    public BigDecimal getDebtMoneyTotal() {
        return debtMoneyTotal;
    }

    public void setDebtMoneyTotal(BigDecimal debtMoneyTotal) {
        this.debtMoneyTotal = debtMoneyTotal;
    }

    public BigDecimal getTaxCurrentTotal() {
        return taxCurrentTotal;
    }

    public void setTaxCurrentTotal(BigDecimal taxCurrentTotal) {
        this.taxCurrentTotal = taxCurrentTotal;
    }

    public BigDecimal getTotalMoneyTax() {
        return totalMoneyTax;
    }

    public void setTotalMoneyTax(BigDecimal totalMoneyTax) {
        this.totalMoneyTax = totalMoneyTax;
    }
}

==> ejc-budgetmanage-impl-3.0.0-20240528.015635-206-sources.jar: com/ejianc/business/bedget/vo/PaymentDetailVO.java <==
package com.ejianc.business.bedget.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 付款登记子表
 * 
 * @author generator
 * 
 */
public class PaymentDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long projectId; // 项目主键
    private String projectName; // 项目名称
    private Long paymentId; // 主表主键
    private Long contractId; // 合同主键
    private String contractName; // 合同名称
    private String contractCode; // 合同编号
    private Long supplierId; // 分包分供id
    private String supplierName; // 分包分供名称
    private String subcontractType; // 分包类型
    private BigDecimal contractAmountTax; // 合同额（含税）
    private String isComplete; // 是否完工结算 是/否
    private BigDecimal settlementMoneyTotal; // 累计结算金额（含税）
    private BigDecimal copeWithRatioTotal; // 应付比例%
    private BigDecimal advanceTotal; // 累计应付金额  预付账款
    private BigDecimal scheduleTotal; // 累计应付金额  进度账款
    private BigDecimal pastAdvanceTotal;//往期累计预付账款
    private BigDecimal pastScheduleTotal;//往期累计进度账款
    private BigDecimal accountsPayableTotal; // 累计应付金额合计
    private BigDecimal currentAdvanceMoney; // 本期实付金额 预付款金额
    private BigDecimal currentScheduleMoney; // 本期实付金额 进度款
    private BigDecimal currentMoneyTotal; // 本期实付金额合计
    private BigDecimal paymentAdvanceMoney; // 累计付款金额（含本期) 预付账款
    private BigDecimal paymentScheduleMoney; // 累计付款金额（含本期) 进度账款
    private BigDecimal paymentMoneyTotal; // 累计付款金额（含本期）合计
    private BigDecimal paymentCopeWithRatio; // 累计付款金额（含本期)  累计支付比例%
    private BigDecimal debtAdvanceMoney; // 累计欠款金额 预付账款
    private BigDecimal debtScheduleMoney; // 累计欠款金额 进度账款
    private BigDecimal debtMoneyTotal; // 累计欠款金额 合计
    private BigDecimal taxCurrentTotal; // 中间计量含税金额
    private BigDecimal totalMoneyTax; // 最终结算含税金额
    @TableField(value="current_salary_money")
    private BigDecimal currentSalaryMoney; // 其中农名工工资(本期实付金额)
    @TableField(value="payment_salary_money")
    private BigDecimal paymentSalaryMoney; // 其中农名工工资(累计付款金额（含本期）)
    @TableField(value="past_salary_total")
    private BigDecimal pastSalaryTotal;//往期 累计农民工工资金额
    private String errorMsg; // 导入错误信息

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }

    public BigDecimal getPastSalaryTotal() {
        return pastSalaryTotal;
    }

    public void setPastSalaryTotal(BigDecimal pastSalaryTotal) {
        this.pastSalaryTotal = pastSalaryTotal;
    }

    public BigDecimal getCurrentSalaryMoney() {
        return currentSalaryMoney;
    }

    public void setCurrentSalaryMoney(BigDecimal currentSalaryMoney) {
        this.currentSalaryMoney = currentSalaryMoney;
    }

    public BigDecimal getPaymentSalaryMoney() {
        return paymentSalaryMoney;
    }

    public void setPaymentSalaryMoney(BigDecimal paymentSalaryMoney) {
        this.paymentSalaryMoney = paymentSalaryMoney;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public Long getPaymentId() {
        return paymentId;
    }

    public void setPaymentId(Long paymentId) {
        this.paymentId = paymentId;
    }

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }

    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }

    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }

    public String getSubcontractType() {
        return subcontractType;
    }

    public void setSubcontractType(String subcontractType) {
        this.subcontractType = subcontractType;
    }

    public BigDecimal getContractAmountTax() {
        return contractAmountTax;
    }

    public void setContractAmountTax(BigDecimal contractAmountTax) {
        this.contractAmountTax = contractAmountTax;
    }

    public String getIsComplete() {
        return isComplete;
    }

    public void setIsComplete(String isComplete) {
        this.isComplete = isComplete;
    }

    public BigDecimal getSettlementMoneyTotal() {
        return settlementMoneyTotal;
    }

    public void setSettlementMoneyTotal(BigDecimal settlementMoneyTotal) {
        this.settlementMoneyTotal = settlementMoneyTotal;
    }

    public BigDecimal getCopeWithRatioTotal() {
        return copeWithRatioTotal;
    }

    public void setCopeWithRatioTotal(BigDecimal copeWithRatioTotal) {
        this.copeWithRatioTotal = copeWithRatioTotal;
    }

    public BigDecimal getAdvanceTotal() {
        return advanceTotal;
    }

    public void setAdvanceTotal(BigDecimal advanceTotal) {
        this.advanceTotal = advanceTotal;
    }

    public BigDecimal getScheduleTotal() {
        return scheduleTotal;
    }

    public void setScheduleTotal(BigDecimal scheduleTotal) {
        this.scheduleTotal = scheduleTotal;
    }

    public BigDecimal getPastAdvanceTotal() {
        return pastAdvanceTotal;
    }

    public void setPastAdvanceTotal(BigDecimal pastAdvanceTotal) {
        this.pastAdvanceTotal = pastAdvanceTotal;
    }

    public BigDecimal getPastScheduleTotal() {
        return pastScheduleTotal;
    }

    public void setPastScheduleTotal(BigDecimal pastScheduleTotal) {
        this.pastScheduleTotal = pastScheduleTotal;
    }

    public BigDecimal getAccountsPayableTotal() {
        return accountsPayableTotal;
    }

    public void setAccountsPayableTotal(BigDecimal accountsPayableTotal) {
        this.accountsPayableTotal = accountsPayableTotal;
    }

    public BigDecimal getCurrentAdvanceMoney() {
        return currentAdvanceMoney;
    }

    public void setCurrentAdvanceMoney(BigDecimal currentAdvanceMoney) {
        this.currentAdvanceMoney = currentAdvanceMoney;
    }

    public BigDecimal getCurrentScheduleMoney() {
        return currentScheduleMoney;
    }

    public void setCurrentScheduleMoney(BigDecimal currentScheduleMoney) {
        this.currentScheduleMoney = currentScheduleMoney;
    }

    public BigDecimal getCurrentMoneyTotal() {
        return currentMoneyTotal;
    }

    public void setCurrentMoneyTotal(BigDecimal currentMoneyTotal) {
        this.currentMoneyTotal = currentMoneyTotal;
    }

    public BigDecimal getPaymentAdvanceMoney() {
        return paymentAdvanceMoney;
    }

    public void setPaymentAdvanceMoney(BigDecimal paymentAdvanceMoney) {
        this.paymentAdvanceMoney = paymentAdvanceMoney;
    }

    public BigDecimal getPaymentScheduleMoney() {
        return paymentScheduleMoney;
    }

    public void setPaymentScheduleMoney(BigDecimal paymentScheduleMoney) {
        this.paymentScheduleMoney = paymentScheduleMoney;
    }

    public BigDecimal getPaymentMoneyTotal() {
        return paymentMoneyTotal;
    }

    public void setPaymentMoneyTotal(BigDecimal paymentMoneyTotal) {
        this.paymentMoneyTotal = paymentMoneyTotal;
    }

    public BigDecimal getPaymentCopeWithRatio() {
        return paymentCopeWithRatio;
    }

    public void setPaymentCopeWithRatio(BigDecimal paymentCopeWithRatio) {
        this.paymentCopeWithRatio = paymentCopeWithRatio;
    }

    public BigDecimal getDebtAdvanceMoney() {
        return debtAdvanceMoney;
    }

    public void setDebtAdvanceMoney(BigDecimal debtAdvanceMoney) {
        this.debtAdvanceMoney = debtAdvanceMoney;
    }

    public BigDecimal getDebtScheduleMoney() {
        return debtScheduleMoney;
    }

    public void setDebtScheduleMoney(BigDecimal debtScheduleMoney) {
        this.debtScheduleMoney = debtScheduleMoney;
    }

    public BigDecimal getDebtMoneyTotal() {
        return debtMoneyTotal;
    }

    public void setDebtMoneyTotal(BigDecimal debtMoneyTotal) {
        this.debtMoneyTotal = debtMoneyTotal;
    }

    public BigDecimal getTaxCurrentTotal() {
        return taxCurrentTotal;
    }

    public void setTaxCurrentTotal(BigDecimal taxCurrentTotal) {
        this.taxCurrentTotal = taxCurrentTotal;
    }

    public BigDecimal getTotalMoneyTax() {
        return totalMoneyTax;
    }

    public void setTotalMoneyTax(BigDecimal totalMoneyTax) {
        this.totalMoneyTax = totalMoneyTax;
    }
}
